<?php
if(!class_exists('The100_Welcome')) :

	class The100_Welcome {

			public $tab_sections = array(); // Welcome Page Tab Sections
			public $theme_name = null; // For storing Theme Name
			public $theme_slug = null; // For storing Theme Slug
			public $theme_version = null; // For Storing Theme Current Version Information
			public $free_plugins = array(); // Displayed Under Recommended Tabs
			public $pro_plugins = array(); // Will be displayed under Recommended Plugins
			public $req_plugins = array(); // Will be displayed under Required Plugins Tab
			public $companion_plugins = array(); // Will be displayed under Demo Import Tab
			public $strings = array(); // Common Display Strings

			
			public function __construct( $plugins, $strings ) {
				/** Useful Variables **/
				$theme = wp_get_theme();
				$this->theme_name = $theme->Name;
				$this->theme_slug = $theme->TextDomain;
				$this->theme_version = $theme->Version;

				/** Plugins **/
				$this->free_plugins = $plugins['recommended_plugins']['free_plugins'];
				$this->pro_plugins = $plugins['recommended_plugins']['pro_plugins'];
				$this->req_plugins = $plugins['required_plugins'];
				$this->companion_plugins = $plugins['companion_plugins'];

				/** Tabs **/
				$this->tab_sections = array(
					'getting_started' => esc_html__('Getting Started', 'the100'),
					'recommended_plugins' => esc_html__('Recommended Plugins', 'the100'),
					//'actions_required' => esc_html__('Required Plugins', 'the100'),
					'demo_import' => esc_html__('Import Demo', 'the100'),
					'support' => esc_html__('Support', 'the100'),
					'changelog' => esc_html__('Changelog', 'the100'),
					'more_wp' => esc_html__('More WordPress Stuff', 'the100'),
				);

				/** Strings **/
				$this->strings = $strings;

				/* Theme Activation Notice */
				add_action( 'load-themes.php', array( $this, 'activation_admin_notice' ));

				/* Create a Welcome Page */
				add_action( 'admin_menu', array( $this, 'welcome_register_menu' ) );

				/* Enqueue Styles & Scripts for Welcome Page */
				add_action( 'admin_enqueue_scripts', array( $this, 'welcome_styles_and_scripts' ) );

				/** WordPress Plugin Installation Ajax **/
				add_action( 'wp_ajax_plugin_installer', array( $this, 'plugin_installer_callback' ) );

				/** Bundled & Remote Plugin Installation Ajax **/
				add_action( 'wp_ajax_plugin_offline_installer', array( $this, 'plugin_offline_installer_callback' ) );

				/** Plugin Activation Ajax **/
				add_action( 'wp_ajax_plugin_activation', array( $this, 'plugin_activation_callback' ) );

				/** Plugin Deactivation Ajax **/
				add_action( 'wp_ajax_plugin_deactivation', array( $this, 'plugin_deactivation_callback' ) );

				add_action( 'init', array( $this, 'get_required_plugin_notification' ));

			}

			public function get_required_plugin_notification() {

				$req_plugins = $this->companion_plugins;
				$notif_counter = count($this->companion_plugins);

				foreach($req_plugins as $plugin) {

					if( isset( $plugin['class'] ) ) {
						if( class_exists( $plugin['class'] ) ) {
							$notif_counter--;
						}
					}
				}
				return $notif_counter;
			}

			/** Welcome Message Notification on Theme Activation **/
			public function activation_admin_notice() {

				global $pagenow;

				if( is_admin() && ('themes.php' == $pagenow) && (isset($_GET['activated'])) ) {

					add_action( 'admin_notices', array( $this,'welcome_admin_notice_display') );
				}
				
			}

			public function welcome_admin_notice_display(){
				
				$the100_an_div = '
				<div class="updated the100-an notice notice-success is-dismissible">
				%1$s
				<hr/>
				<div class="the100-column-wrap">
				<div class="the100-column col-img">%2$s</div>
				<div class="the100-column col-demos">%3$s</div>
				<div class="the100-column col-doc">%4$s</div>
				</div> 
				</div>
				<style>%5$s</style>';

				/* translators: 1 - notice title, 2 - notice message */
				$the100_an_top = sprintf(
					'<h2>%1$s</h2><p class="about-desc">%2$s</p></hr>',
					esc_html__( 'Congratulations!', 'the100' ),
					sprintf(
						/* translators: %s - theme name */
						esc_html__( '%s is now installed and ready to use. We\'ve assembled some links to get you started.', 'the100' ),
						$this->theme_name
					)
				);

				$the100_an_btn = sprintf(
					/* translators: 1 - url, 2 - button text */
					'<a href="%1$s" class="button button-primary the100-btn" >%2$s</a>',
					esc_url( admin_url( 'themes.php?page=welcome-page#demo_import' ) ),
					esc_html__( 'Try one of our ready to use Starter Sites', 'the100' )
				);
				$the100_an_pbtn = sprintf(
					/* translators: 1 - options page url, 2 - button text */
					'<a href="%1$s" class="options-page-btn">%2$s</a>',
					esc_url( admin_url( 'themes.php?page=the100-about' ) ),
					esc_html__( 'or go to the theme settings', 'the100' )
				);
				$the100_an_img = sprintf(
					'<picture>
					<source srcset="about:blank" media="(max-width: 1024px)">
					<img src="%1$s">
					</picture>',
					esc_url( get_template_directory_uri() . '/screenshot.png' )
				);
				$the100_an_list = sprintf(
					'<div><h3><span class="dashicons dashicons-images-alt2"></span> %1$s</h3><p>%2$s</p></div><div> <p>%3$s</p><p>%4$s</p> </div>',
					__( 'Sites Library', 'the100' ),
					// translators: %s - theme name
					sprintf( esc_html__( '%s now comes with a sites library with various designs to pick from. Visit our collection of demos that are constantly being added.', 'the100' ), $this->theme_name ),
					$the100_an_btn,
					$the100_an_pbtn
				);
				$the100_an_doc = sprintf(
					'<div><h3><span class="dashicons dashicons-format-aside"></span> %1$s</h3><p>%2$s</p><a class="button the100-btn" href="%3$s">%4$s</a></div><div></div>',
					__( 'Documentation', 'the100' ),
					// translators: %s - theme name
					sprintf( esc_html__( 'Need more details? Please check our full documentation for detailed information on how to use %s.', 'the100' ), $this->theme_name ),
					'https://8degreethemes.com/documentation/the100',
					esc_html__( 'Read full documentation', 'the100' )
				);
				$the100_an_style = '
				.the100-an.notice.is-dismissible {padding: 20px 15px 5px;}
				.the100-an hr {margin: 20px -23px 0;border-top: 1px solid #f3f4f5;border-bottom: none;}
				.the100-an h3{margin: 17px 0 0;font-size: 16px;line-height: 1.4;}
				.the100-an p {color: #72777c;}
				.the100-an h2{margin: 0;font-size: 21px;font-weight: 400;line-height: 1.2;}
				.the100-an p.about-desc{color: #72777c;font-size: 16px;margin: 0;padding:0px;}
				.the100-column-wrap {display: -ms-grid;display: grid;-ms-grid-columns: 24% 32% 32%;grid-template-columns: 24% 32% 32%;margin-bottom: 13px;}
				.the100-column {padding: 20px 40px 0 0;}
				.the100-an .the100-btn {padding: 30px;line-height: 0;}';

				echo sprintf(
					$the100_an_div,
					$the100_an_top,
					$the100_an_img,
					$the100_an_list,
					$the100_an_doc,
					$the100_an_style
				);// WPCS: XSS OK.
				
			}

			/** Register Menu for Welcome Page **/
			public function welcome_register_menu() {
				$action_count = $this->get_required_plugin_notification();
				$title        = $action_count > 0 ? esc_html($this->strings['welcome_menu_text']) . '<span class="badge pending-tasks">' . esc_html( $action_count ) . '</span>' : esc_html($this->strings['welcome_menu_text']);
				add_theme_page( esc_html($this->strings['welcome_menu_text']), $title , 'edit_theme_options', 'welcome-page', array( $this, 'welcome_screen' ));
			}

			/** Welcome Page **/
			public function welcome_screen() {
				$tabs = $this->tab_sections;

				$current_section = isset($_GET['section']) ? sanitize_text_field( wp_unslash( $_GET['section'] ) ) : 'getting_started';
				$section_inline_style = '';
				?>
				<div class="wrap about-wrap access-wrap">					
					<div class="top-block-wrap">					
						<h1><?php /* translators: %1$s: theme name, %2$s: theme version */ printf( esc_html__( 'Welcome to %1$s - Version %2$s', 'the100' ), esc_html($this->theme_name), esc_html($this->theme_version) ); ?></h1>
						<div class="about-text"><?php echo esc_html($this->strings['theme_short_description']); ?></div>

						<a target="_blank" href="https://www.8degreethemes.com" class="eightdegree-badge wp-badge"><span><?php echo esc_html('8DegreeThemes', $this->theme_slug); ?></span></a>						
					</div>
					<div class="bottom-block-wrap">
						<div class="nav-tab-wrapper clearfix">
							<?php foreach($tabs as $id => $label) : ?>
								<a href="<?php echo esc_url(admin_url('themes.php?page=welcome-page#'.$id)); ?>" class="nav-tab <?php echo esc_attr($id);?> nav-tab-inactive" >
									<?php echo esc_html( $label ); ?>
									<?php if($id == 'actions_required') : $not = $this->get_required_plugin_notification(); ?>
										<?php if($not) : ?>
											<span class="pending-tasks">
												<?php echo esc_html($not); ?>
											</span>
										<?php endif; ?>
									<?php endif; ?>
								</a>
							<?php endforeach; ?>
						</div>
						<div class="welcome-section-wrapper-loader import-php updating-message"></div>
						<div class="welcome-section-wrapper is_loading">
							<?php foreach($tabs as $id => $label) : ?>
								<div class="welcome-section <?php echo esc_attr($id);?> nav-tab-inactive clearfix">
									<?php require_once get_template_directory() . '/welcome/sections/'.esc_html($id).'.php'; ?>
								</div>
							<?php endforeach; ?>
						</div>
					</div>
				</div>
				<?php
			}

			/** Enqueue Necessary Styles and Scripts for the Welcome Page **/
			public function welcome_styles_and_scripts() {
				wp_enqueue_style( $this->theme_slug . '-welcome-screen', get_template_directory_uri() . '/welcome/css/welcome.css' );
				wp_enqueue_script( $this->theme_slug . '-welcome-screen', get_template_directory_uri() . '/welcome/js/welcome.js', array( 'jquery' ) );

				wp_localize_script( $this->theme_slug . '-welcome-screen', 'SmWelcomeObject', array(
					'admin_nonce'	=> wp_create_nonce( 'plugin_installer_nonce'),
					'activate_nonce'	=> wp_create_nonce( 'plugin_activate_nonce'),
					'deactivate_nonce'	=> wp_create_nonce( 'plugin_deactivate_nonce'),
					'ajaxurl'		=> esc_url( admin_url( 'admin-ajax.php' ) ),
					'activate_btn' => $this->strings['activate'],
					'installed_btn' => $this->strings['installed_btn'],
					'demo_installing' => $this->strings['demo_installing'],
					'demo_installed' => $this->strings['demo_installed'],
					'demo_confirm' => $this->strings['demo_confirm'],
				) );
			}

			/** Plugin API **/
			public function call_plugin_api( $plugin ) {
				include_once ABSPATH . 'wp-admin/includes/plugin-install.php';

				$call_api = plugins_api( 'plugin_information', array(
					'slug'   => $plugin,
					'fields' => array(
						'downloaded'        => false,
						'rating'            => false,
						'description'       => false,
						'short_description' => true,
						'donate_link'       => false,
						'tags'              => false,
						'sections'          => true,
						'homepage'          => true,
						'added'             => false,
						'last_updated'      => false,
						'compatibility'     => false,
						'tested'            => false,
						'requires'          => false,
						'downloadlink'      => false,
						'icons'             => true
					)
				) );

				return $call_api;
			}

			/** Check For Icon **/
			public function check_for_icon( $arr ) {
				if ( ! empty( $arr['svg'] ) ) {
					$plugin_icon_url = $arr['svg'];
				} elseif ( ! empty( $arr['2x'] ) ) {
					$plugin_icon_url = $arr['2x'];
				} elseif ( ! empty( $arr['1x'] ) ) {
					$plugin_icon_url = $arr['1x'];
				} else {
					$plugin_icon_url = $arr['default'];
				}

				return $plugin_icon_url;
			}

			/** Check if Plugin is active or not **/
			public function get_plugin_active($plugin) {
				$folder_name = $plugin['slug'];
				$file_name = $plugin['filename'];
				
				$class = '';
				if( isset($plugin['class']) ){
					$class = $plugin['class'];	
				}
				
				$function = '';
				if( isset($plugin['function']) ){
					$function = $plugin['function'];
				}
				
				$status = 'install';

				$path = WP_PLUGIN_DIR.'/'.esc_attr($folder_name).'/'.esc_attr($file_name);
				if( file_exists( $path ) ) {
					if($class){
						$status = class_exists( $class ) ? 'inactive' : 'active';	
					}elseif($function){
						$status = function_exists( $function ) ? 'inactive' : 'active';	
					}
					
				}
				return $status;
			}

			/** Generate Url for the Plugin Button **/
			public function generate_plugin_url($status, $plugin) {
				$folder_name = $plugin['slug'];
				$file_name = $plugin['filename'];

				switch ( $status ) {
					case 'install':
					return wp_nonce_url(
						add_query_arg(
							array(
								'action' => 'install-plugin',
								'plugin' => esc_attr($folder_name)
							),
							network_admin_url( 'update.php' )
						),
						'install-plugin_' . esc_attr($folder_name)
					);
					break;

					case 'inactive':
					return '#';
					break;

					case 'active':
					return '#';
					break;
				}
			}

			/* ========== Plugin Installation Ajax =========== */
			public function plugin_installer_callback(){

				if ( ! current_user_can('install_plugins') ) {
					wp_die( esc_html__( 'Sorry, you are not allowed to install plugins on this site.', 'the100' ) );
				}

				$nonce = isset( $_POST["nonce"] ) ? sanitize_text_field( wp_unslash( $_POST["nonce"] ) ) : '';
				$plugin = isset( $_POST["plugin"] ) ? sanitize_text_field( wp_unslash( $_POST["plugin"] ) ) : '';
				$plugin_file = isset( $_POST["plugin_file"] ) ? sanitize_text_field( wp_unslash( $_POST["plugin_file"] ) ) : '';

				// Check our nonce, if they don't match then bounce!
				if (! wp_verify_nonce( $nonce, 'plugin_installer_nonce' )) {
					wp_die( esc_html__( 'Error - unable to verify nonce, please try again.', 'the100') );
				}


         		// Include required libs for installation
				require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
				require_once ABSPATH . 'wp-admin/includes/class-wp-ajax-upgrader-skin.php';
				require_once ABSPATH . 'wp-admin/includes/class-plugin-upgrader.php';

				// Get Plugin Info
				$api = $this->call_plugin_api($plugin);

				$skin     = new WP_Ajax_Upgrader_Skin();
				$upgrader = new Plugin_Upgrader( $skin );
				$upgrader->install($api->download_link);

				$plugin_file = esc_html($plugin).'/'.esc_html($plugin_file);

				if($api->name) {
					if($plugin_file) {
						activate_plugin($plugin_file);
						echo 'success';
						die();
					}
				}
				echo 'fail';

				die();
			}

			/** Plugin Offline Installation Ajax **/
			public function plugin_offline_installer_callback() {
				$plugin = array();

				$file_location = $plugin['location'] = isset( $_POST['file_location'] ) ? sanitize_text_field( wp_unslash( $_POST['file_location'] ) ) : '';
				$file = isset( $_POST['file'] ) ? sanitize_text_field( wp_unslash( $_POST['file'] ) ) : '';
				$host_type = isset( $_POST['host_type'] ) ? sanitize_text_field( wp_unslash( $_POST['host_type'] ) ) : '';
				$plugin_class = $plugin['class'] = isset( $_POST['class_name'] ) ? sanitize_text_field( wp_unslash( $_POST['class_name'] ) ) : '';
				$plugin_slug = $plugin['slug'] = isset( $_POST['slug'] ) ? sanitize_text_field( wp_unslash( $_POST['slug'] ) ) : '';
				$plugin_directory = ABSPATH . 'wp-content/plugins/';

				$plugin_file = $plugin_slug . '/' . $file;

				if( $host_type == 'remote' ) {
					$file_location = $this->get_local_dir_path($plugin);
				}

				$zip = new ZipArchive();
				if ($zip->open($file_location) === TRUE) {
					$zip->extractTo($plugin_directory);
					$zip->close();

					activate_plugin($plugin_file);

					if( $host_type == 'remote' ) {
						unlink($file_location);
					}

					echo 'success';

					die();
				} else {
					echo 'failed';
				}

				die();
			}

			/** Plugin Offline Activation Ajax **/
			public function plugin_activation_callback() {

				$plugin = isset( $_POST['plugin'] ) ? sanitize_text_field( wp_unslash( $_POST['plugin'] ) ) : '';
				$plugin_file = isset( $_POST['plugin_file'] ) ? sanitize_text_field( wp_unslash( $_POST['plugin_file'] ) ) : '';
				$plugin_file = ABSPATH . 'wp-content/plugins/'.esc_html($plugin).'/'.esc_html($plugin_file);

				if(file_exists($plugin_file)) {

					activate_plugin($plugin_file);
					echo "success";

				} else {
					echo esc_html__('Plugin Does not Exists' , 'the100');
				}

				die();

			}

			/** Plugin Offline Activation Ajax **/
			public function plugin_deactivation_callback() {

				$plugin = isset( $_POST['plugin'] ) ? sanitize_text_field( wp_unslash( $_POST['plugin'] ) ) : '';
				$plugin_file = isset( $_POST['plugin_file'] ) ? sanitize_text_field( wp_unslash( $_POST['plugin_file'] ) ) : '';
				$plugin_file = ABSPATH . 'wp-content/plugins/'.esc_html($plugin).'/'.esc_html($plugin_file);

				if(file_exists($plugin_file)) {

					deactivate_plugins($plugin_file);
					echo "success";

				} else {
					echo esc_html__('Plugin Does not Exists' , 'the100');
				}

				die();

			}

			public function all_required_plugins_installed() {

				$companion_plugins = $this->companion_plugins;
				$show_success_notice = false;

				foreach($companion_plugins as $plugin) {

					$path = WP_PLUGIN_DIR.'/'.esc_attr($plugin['slug']).'/'.esc_attr($plugin['filename']);

					if(file_exists($path)) {
						if(class_exists($plugin['class'])) {
							$show_success_notice = true;
						} else {
							$show_success_notice = false;
							break;
						}
					} else {
						$show_success_notice = false;
						break;
					}
				}

				return $show_success_notice;
			}

			public function get_local_dir_path($plugin) {

				$upload_dir = wp_upload_dir();

				$file_location = $upload_dir['path'] . '/' . $plugin['slug'].'.zip';

				if( file_exists( $file_location ) || class_exists( $plugin['class'] ) ) {
					return $file_location;
				}

				$url = wp_nonce_url(admin_url('themes.php?page=' . $this->theme_slug . '-welcome&section=actions_required'),'remote-file-installation');
				if (false === ($creds = request_filesystem_credentials($url, '', false, false, null) ) ) {
					return; // stop processing here
				}

				if ( ! WP_Filesystem($creds) ) {
					request_filesystem_credentials($url, '', true, false, null);
					return;
				}

				global $wp_filesystem;
				$file = $wp_filesystem->get_contents( $plugin['location'] );

				$wp_filesystem->put_contents( $file_location, $file, FS_CHMOD_FILE );

				return $file_location;
			}

		}

	endif;

	/** Initializing Demo Importer if exists **/
	if(class_exists('Instant_Demo_Importer')) :
		$demoimporter = new Instant_Demo_Importer();

		$demoimporter->demos = array(
			'the100-classic' => array(
				'title' => __('Classic Demo', 'the100'),
				'name' => 'classic',
				'screenshot' => 'https://8degreethemes.com/resource/img/classic.jpg',
				'home_page' => 'homepage',
				'menus' => array(
					'Primary Menu' => 'menu-1'
				)
			),
			'the100-construction' => array(
				'title' => __('Construction Demo', 'the100'),
				'name' => 'construction',
				'screenshot' => 'https://8degreethemes.com/resource/img/construction.jpg',
				'home_page' => 'homepage',
				'menus' => array(
					'Primary Menu' => 'menu-1'
				)
			),
			'the100-restaurant' => array(
				'title' => __('Restaurant Demo', 'the100'),
				'name' => 'restaurant',
				'screenshot' => 'https://8degreethemes.com/resource/img/restaurant.jpg',
				'home_page' => 'homepage',
				'menus' => array(
					'Primary Menu' => 'menu-1',
					'Left of Logo' => 'menu-2'
				)
			),
			'the100-events' => array(
				'title' => __('Events Demo', 'the100'),
				'name' => 'events',
				'screenshot' => 'https://8degreethemes.com/resource/img/events.jpg',
				'home_page' => 'homepage',
				'menus' => array(
					'Primary Menu' => 'menu-1'
				)
			),
			'the100-charity' => array(
				'title' => __('Charity Demo', 'the100'),
				'name' => 'charity',
				'screenshot' => 'https://8degreethemes.com/resource/img/charity.jpg',
				'home_page' => 'homepage',
				'menus' => array(
					'Primary Menu' => 'menu-1'
				)
			),
		);

		$demoimporter->demo_dir = get_template_directory().'/welcome/demo/'; // Path to the directory containing demo files
		$demoimporter->options_replace_url = ''; // Set the url to be replaced with current siteurl
		$demoimporter->option_name = ''; // Set the the name of the option if the theme is based on theme option
	endif;


	/** adding ocdi compatibility */
	function the100_ocdi_import_files() {
		return array(
			array(
				'import_file_name'             => 'The100 Classic Demo',
				'local_import_file'            => trailingslashit( get_template_directory() ) . 'welcome/demo/classic/content.xml',
				'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'welcome/demo/classic/widgets.wie',
				'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'welcome/demo/classic/customizer_options.dat',
				'import_preview_image_url'     => 'https://8degreethemes.com/resource/img/classic.jpg',
				'import_notice'                => __( 'After you import this demo, you might have to setup the menu separately.', 'the100' ),
				'preview_url'                  => 'https://8degreethemes.com/demo/the100/classic',
			),
			array(
				'import_file_name'             => 'The100 Construction Demo',
				'local_import_file'            => trailingslashit( get_template_directory() ) . 'welcome/demo/construction/content.xml',
				'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'welcome/demo/construction/widgets.wie',
				'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'welcome/demo/construction/customizer_options.dat',
				'import_preview_image_url'     => 'https://8degreethemes.com/resource/img/construction.jpg',
				'import_notice'                => __( 'After you import this demo, you might have to setup the menu separately.', 'the100' ),
				'preview_url'                  => 'https://8degreethemes.com/demo/the100/construction',
			),
			array(
				'import_file_name'             => 'The100 Restaurant Demo',
				'local_import_file'            => trailingslashit( get_template_directory() ) . 'welcome/demo/restaurant/content.xml',
				'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'welcome/demo/restaurant/widgets.wie',
				'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'welcome/demo/restaurant/customizer_options.dat',
				'import_preview_image_url'     => 'https://8degreethemes.com/resource/img/restaurant.jpg',
				'import_notice'                => __( 'After you import this demo, you might have to setup the menu separately.', 'the100' ),
				'preview_url'                  => 'https://8degreethemes.com/demo/the100/restaurant',
			),
			array(
				'import_file_name'             => 'The100 Events Demo',
				'local_import_file'            => trailingslashit( get_template_directory() ) . 'welcome/demo/events/content.xml',
				'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'welcome/demo/events/widgets.wie',
				'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'welcome/demo/events/customizer_options.dat',
				'import_preview_image_url'     => 'https://8degreethemes.com/resource/img/events.jpg',
				'import_notice'                => __( 'After you import this demo, you might have to setup the menu separately.', 'the100' ),
				'preview_url'                  => 'https://8degreethemes.com/demo/the100/events',
			),
			array(
				'import_file_name'             => 'The100 Charity Demo',
				'local_import_file'            => trailingslashit( get_template_directory() ) . 'welcome/demo/charity/content.xml',
				'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'welcome/demo/charity/widgets.wie',
				'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'welcome/demo/charity/customizer_options.dat',
				'import_preview_image_url'     => 'https://8degreethemes.com/resource/img/charity.jpg',
				'import_notice'                => __( 'After you import this demo, you might have to setup the menu separately.', 'the100' ),
				'preview_url'                  => 'https://8degreethemes.com/demo/the100/charity',
			)
		);
	}
	add_filter( 'pt-ocdi/import_files', 'the100_ocdi_import_files' );


	function the100_ocdi_after_import( $selected_import ) {
		// Assign menus to their locations.
		$main_menu = get_term_by( 'name', 'Menu 1', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations', array(
			'primary' => $main_menu->term_id,
		));

		// Assign front page and posts page (blog page).
		$front_page_id = get_page_by_title( 'Homepage' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
	}
	add_action( 'pt-ocdi/after_import', 'the100_ocdi_after_import' );